#ifndef SETTINGS_H
#define SETTINGS_H
#include <qstring.h>
#include <QSettings>

class Settings
{
    QSettings m_settings;
public:
    QString getAPIkey();
    bool setAPIkey(QString);
    QString getAdress();
    bool setAddress(QString);
    int getPort();
    bool setPort(QString);
    QString getUsername();
    bool setUsername(QString);
    QString getPassword();
    bool setPassword(QString);
    Settings();
    ~Settings();
};

#endif // SETTINGS_H
